
# `cli-highlight`

> Syntax highlighting in your terminal

[![Version](https://img.shields.io/npm/v/cli-highlight.svg)](https://www.npmjs.com/package/cli-highlight)
[![Downloads](https://img.shields.io/npm/dt/cli-highlight.svg)](https://www.npmjs.com/package/cli-highlight)
[![Build Status](https://travis-ci.org/felixfbecker/cli-highlight.svg?branch=master)](https://travis-ci.org/felixfbecker/cli-highlight)
![Dependencies](https://david-dm.org/felixfbecker/cli-highlight.svg)
![Node Version](http://img.shields.io/node/v/cli-highlight.svg)
[![License](https://img.shields.io/npm/l/cli-highlight.svg)](https://github.com/felixfbecker/cli-highlight/blob/master/LICENSE.txt)

## Example

[![Example Test Output](images/tests.png)](https://travis-ci.org/felixfbecker/cli-highlight)

## CLI Usage
Output a file
```sh
$ highlight package.json
```

Color output of another program with piping. Example: A database migration script that logs SQL Queries
```sh
$ db-migrate --dry-run | highlight
```

Command line options:
```html
Usage: highlight [options] [file]

Outputs a file or STDIN input with syntax highlighting

Options:
  --theme, -t    Use a theme defined in a JSON file
  --version, -v  Show version number                                   [boolean]
  --help, -h     Show help                                             [boolean]
```

## Programmatic Usage

You can use this module programmatically to highlight logs of your Node app. Example:

```js
const highlight = require('cli-highlight').highlight
const Sequelize = require('sequelize')

const db = new Sequelize(process.env.DB, {
  logging(log) {
    console.log(highlight(log, {language: 'sql', ignoreIllegals: true}))
  }
})
```

Detailed API documenation can be found [here](http://cli-highlight.surge.sh/).

## Themes
You can write your own theme in a JSON file and pass it with `--theme`.
The key must be one of the [highlight.js CSS class names](http://highlightjs.readthedocs.io/en/latest/css-classes-reference.html)
and the value must be one or an array of [Chalk styles](https://github.com/chalk/chalk#styles) to be applied to that token.

```json
{
  "keyword": "blue",
  "built_in": ["cyan", "dim"],
  "string": "red"
}
```

The theme is combined with the [default theme](http://cli-highlight.surge.sh/globals.html#default_theme).
The default theme is still not colored a lot or optimized for many languages, PRs welcome!

## Supported Languages
In theory, [all languages of highlight.js](https://highlightjs.org/static/demo/) are supported - I just did not adapt
the default theme and wrote tests for all languages yet. My primary use case was SQL so that is supported well.

## Contributing
The module is written in TypeScript and can be compiled with `npm run build`.
`npm run watch` starts `tsc` in watch mode. Tests are written with mocha.

Improving language support is done by adding more colors to the tokens in the default theme and writing more tests.
